@@ -1,5 +1,5 @@
 
-# $rcs = ' $Id: Charset.pm,v 1.397 2011-09-25 15:22:59 Martin Exp $ ' ;
+# $rcs = ' $Id: Charset.pm,v 1.402 2012-10-13 16:44:46 Martin Exp $ ' ;
 
 package I18N::Charset;
 
@@ -68,7 +68,7 @@ functions will always return undef.
 #	Public Global Variables
 #-----------------------------------------------------------------------
 our
-$VERSION = do { my @r = (q$Revision: 1.397 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 1.402 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 our @EXPORT = qw( iana_charset_name
 map8_charset_name
 umap_charset_name
@@ -1320,11 +1320,16 @@ sub _init_data
   # http://www.iana.org/assignments/character-sets
   return <<'EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE';
 
-===================================================================
 CHARACTER SETS
 
-(last updated 2011-09-23)
+(last updated 2012-10-04)
 
+Registry: Character Sets
+Reference: [RFC2978]
+Registration Procedures: Expert Review
+Experts: Primary Expert Ned Freed and Secondary Expert Martin Duerst
+
+Note:
 These are the official names for character sets that may be used in
 the Internet and may be referred to in Internet documentation.  These
 names are expressed in ANSI_X3.4-1968 which is commonly called
@@ -1377,9 +1382,9 @@ revised, the year of revision is added to the cs alias of the new
 character set entry in the IANA Registry in order to distinguish the
 revised character set from the original character set.
 
-
+Registry:
 Character Set                                               Reference
--------------                                               ---------
+----------------------------------------------------------  ---------
 
 Name: ANSI_X3.4-1968                                   [RFC1345,KXS2]
 MIBenum: 3
@@ -1793,6 +1798,7 @@ MIBenum: 54
 Source: ECMA registry
 Alias: iso-ir-54
 Alias: ISO5427Cyrillic1981
+Alias: csISO54271981
 
 Name: ISO_5428:1980                                     [RFC1345,KXS2]
 MIBenum: 55
@@ -1962,6 +1968,7 @@ Source: ECMA registry
 Alias: iso-ir-121
 Alias: ISO646-CA
 Alias: csa7-1
+Alias: csa71
 Alias: ca
 Alias: csISO121Canadian1
 
@@ -1971,6 +1978,7 @@ Source: ECMA registry
 Alias: iso-ir-122
 Alias: ISO646-CA2
 Alias: csa7-2
+Alias: csa72
 Alias: csISO122Canadian2
 
 Name: CSA_Z243.4-1985-gr                                 [RFC1345,KXS2]
@@ -2128,20 +2136,22 @@ Alias: csUnicode11UTF7
 Name: ISO-2022-CN                                            [RFC1922]
 MIBenum: 104
 Source: RFC-1922
+Alias: csISO2022CN
 
 Name: ISO-2022-CN-EXT                                        [RFC1922]
 MIBenum: 105
 Source: RFC-1922
+Alias: csISO2022CNEXT
 
 Name: UTF-8                                                    [RFC3629]
 MIBenum: 106
 Source: RFC 3629
-Alias: None 
+Alias: csUTF8
 
 Name: ISO-8859-13
 MIBenum: 109
 Source: ISO See (http://www.iana.org/assignments/charset-reg/ISO-8859-13)[Tumasonis] 
-Alias: None
+Alias: csISO885913
 
 Name: ISO-8859-14
 MIBenum: 110
@@ -2152,6 +2162,7 @@ Alias: ISO_8859-14
 Alias: latin8
 Alias: iso-celtic
 Alias: l8
+Alias: csISO885914
 
 Name: ISO-8859-15
 MIBenum: 111
@@ -2159,6 +2170,7 @@ Source: ISO
         Please see: <http://www.iana.org/assignments/charset-reg/ISO-8859-15>
 Alias: ISO_8859-15
 Alias: Latin-9
+Alias: csISO885915
 
 Name: ISO-8859-16
 MIBenum: 112
@@ -2168,6 +2180,7 @@ Alias: ISO_8859-16:2001
 Alias: ISO_8859-16
 Alias: latin10
 Alias: l10 
+Alias: csISO885916
 
 Name: GBK                                                 
 MIBenum: 113
@@ -2176,30 +2189,31 @@ Source: Chinese IT Standardization Technical Committee
 Alias: CP936
 Alias: MS936
 Alias: windows-936
+Alias: csGBK
 
 Name: GB18030
 MIBenum: 114
 Source: Chinese IT Standardization Technical Committee
         Please see: <http://www.iana.org/assignments/charset-reg/GB18030>
-Alias: None
+Alias: csGB18030
 
 Name:  OSD_EBCDIC_DF04_15
 MIBenum:  115
 Source:  Fujitsu-Siemens standard mainframe EBCDIC encoding
          Please see: <http://www.iana.org/assignments/charset-reg/OSD-EBCDIC-DF04-15>
-Alias:   None
+Alias:   csOSDEBCDICDF0415
 
 Name:  OSD_EBCDIC_DF03_IRV
 MIBenum:  116
 Source:  Fujitsu-Siemens standard mainframe EBCDIC encoding
          Please see: <http://www.iana.org/assignments/charset-reg/OSD-EBCDIC-DF03-IRV>
-Alias:  None
+Alias:  csOSDEBCDICDF03IRV
 
 Name:  OSD_EBCDIC_DF04_1
 MIBenum:  117
 Source:  Fujitsu-Siemens standard mainframe EBCDIC encoding
          Please see: <http://www.iana.org/assignments/charset-reg/OSD-EBCDIC-DF04-1>
-Alias:  None   
+Alias:  csOSDEBCDICDF041 
 
 Name: ISO-11548-1
 MIBenum: 118 
@@ -2243,7 +2257,9 @@ Alias: csUnicodeLatin1
 Alias: ISO-10646
 
 Name: ISO-10646-J-1
+MIBenum: 1004
 Source: ISO 10646 Japanese, see RFC 1815.
+Alias: csUnicodeJapanese
 
 Name: ISO-Unicode-IBM-1261
 MIBenum: 1005
@@ -2278,51 +2294,53 @@ Alias: csUnicode11
 Name: SCSU
 MIBenum: 1011
 Source: SCSU See (http://www.iana.org/assignments/charset-reg/SCSU)     [Scherer]
-Alias: None 
+Alias: csSCSU
 
 Name: UTF-7                                                    [RFC2152]
 MIBenum: 1012
 Source: RFC 2152
-Alias: None
+Alias: csUTF7
 
 Name: UTF-16BE                                                 [RFC2781]
 MIBenum: 1013
 Source: RFC 2781
-Alias: None
+Alias: csUTF16BE
 
 Name: UTF-16LE                                                 [RFC2781]
 MIBenum: 1014
 Source: RFC 2781
-Alias: None
+Alias: csUTF16LE
 
 Name: UTF-16                                                   [RFC2781]
 MIBenum: 1015
 Source: RFC 2781
-Alias: None
+Alias: csUTF16
 
 Name: CESU-8                                                    [Phipps]
 MIBenum: 1016
 Source: <http://www.unicode.org/unicode/reports/tr26>
+Alias: csCESU8
 Alias: csCESU-8
 
 Name: UTF-32                                                     [Davis] 
 MIBenum: 1017
 Source: <http://www.unicode.org/unicode/reports/tr19/>
-Alias: None
+Alias: csUTF32
 
 Name: UTF-32BE                                                   [Davis]
 MIBenum: 1018
 Source: <http://www.unicode.org/unicode/reports/tr19/>
-Alias: None
+Alias: csUTF32BE
 
 Name: UTF-32LE                                                   [Davis]
 MIBenum: 1019
 Source: <http://www.unicode.org/unicode/reports/tr19/>
-Alias: None
+Alias: csUTF32LE
 
 Name: BOCU-1                                                   [Scherer]
 MIBenum: 1020
 Source: http://www.unicode.org/notes/tn6/
+Alias: csBOCU1
 Alias: csBOCU-1
 
 Name: ISO-8859-1-Windows-3.0-Latin-1                           [HP-PCL5] 
@@ -2899,6 +2917,7 @@ Alias: csPC775Baltic
 Name: KOI8-U                                                   [RFC2319]
 MIBenum: 2088
 Source: RFC 2319
+Alias: csKOI8U
 
 Name: IBM00858
 MIBenum: 2089
@@ -2906,6 +2925,7 @@ Source: IBM See (http://www.iana.org/assignments/charset-reg/IBM00858)    [Mahdi
 Alias: CCSID00858
 Alias: CP00858
 Alias: PC-Multilingual-850+euro
+Alias: csIBM00858
 
 Name: IBM00924
 MIBenum: 2090
@@ -2913,6 +2933,7 @@ Source: IBM See (http://www.iana.org/assignments/charset-reg/IBM00924)    [Mahdi
 Alias: CCSID00924
 Alias: CP00924
 Alias: ebcdic-Latin9--euro
+Alias: csIBM00924
 
 Name: IBM01140
 MIBenum: 2091
@@ -2920,6 +2941,7 @@ Source: IBM See (http://www.iana.org/assignments/charset-reg/IBM01140)    [Mahdi
 Alias: CCSID01140
 Alias: CP01140
 Alias: ebcdic-us-37+euro
+Alias: csIBM01140
 
 Name: IBM01141
 MIBenum: 2092
@@ -2927,6 +2949,7 @@ Source: IBM See (http://www.iana.org/assignments/charset-reg/IBM01141)    [Mahdi
 Alias: CCSID01141
 Alias: CP01141
 Alias: ebcdic-de-273+euro
+Alias: csIBM01141
 
 Name: IBM01142
 MIBenum: 2093
@@ -2935,6 +2958,7 @@ Alias: CCSID01142
 Alias: CP01142
 Alias: ebcdic-dk-277+euro
 Alias: ebcdic-no-277+euro
+Alias: csIBM01142
 
 Name: IBM01143
 MIBenum: 2094
@@ -2943,6 +2967,7 @@ Alias: CCSID01143
 Alias: CP01143
 Alias: ebcdic-fi-278+euro
 Alias: ebcdic-se-278+euro
+Alias: csIBM01143
 
 Name: IBM01144
 MIBenum: 2095
@@ -2950,6 +2975,7 @@ Source: IBM See (http://www.iana.org/assignments/charset-reg/IBM01144)    [Mahdi
 Alias: CCSID01144
 Alias: CP01144
 Alias: ebcdic-it-280+euro
+Alias: csIBM01144
 
 Name: IBM01145
 MIBenum: 2096
@@ -2957,6 +2983,7 @@ Source: IBM See (http://www.iana.org/assignments/charset-reg/IBM01145)    [Mahdi
 Alias: CCSID01145
 Alias: CP01145
 Alias: ebcdic-es-284+euro
+Alias: csIBM01145
 
 Name: IBM01146
 MIBenum: 2097
@@ -2964,6 +2991,7 @@ Source: IBM See (http://www.iana.org/assignments/charset-reg/IBM01146)    [Mahdi
 Alias: CCSID01146
 Alias: CP01146
 Alias: ebcdic-gb-285+euro
+Alias: csIBM01146
 
 Name: IBM01147
 MIBenum: 2098
@@ -2971,6 +2999,7 @@ Source: IBM See (http://www.iana.org/assignments/charset-reg/IBM01147)    [Mahdi
 Alias: CCSID01147
 Alias: CP01147
 Alias: ebcdic-fr-297+euro
+Alias: csIBM01147
 
 Name: IBM01148
 MIBenum: 2099
@@ -2978,6 +3007,7 @@ Source: IBM See (http://www.iana.org/assignments/charset-reg/IBM01148)    [Mahdi
 Alias: CCSID01148
 Alias: CP01148
 Alias: ebcdic-international-500+euro
+Alias: csIBM01148
 
 Name: IBM01149
 MIBenum: 2100
@@ -2985,17 +3015,19 @@ Source: IBM See (http://www.iana.org/assignments/charset-reg/IBM01149)    [Mahdi
 Alias: CCSID01149
 Alias: CP01149
 Alias: ebcdic-is-871+euro
+Alias: csIBM01149
 
 Name: Big5-HKSCS                                                  [Yick]
 MIBenum: 2101
 Source:   See (http://www.iana.org/assignments/charset-reg/Big5-HKSCS) 
-Alias: None
+Alias: csBig5HKSCS
 
 Name: IBM1047                                                [Robrigado]
 MIBenum: 2102
 Source: IBM1047 (EBCDIC Latin 1/Open Systems)
 http://www-1.ibm.com/servers/eserver/iseries/software/globalization/pdf/cp01047z.pdf
 Alias: IBM-1047
+Alias: csIBM1047
 
 Name: PTCP154                                                    [Uskov]
 MIBenum: 2103
@@ -3004,6 +3036,7 @@ Alias: csPTCP154
 Alias: PT154
 Alias: CP154
 Alias: Cyrillic-Asian
+Alias: csPTCP154
 
 Name:  Amiga-1251
 MIBenum:  2104
@@ -3012,12 +3045,13 @@ Alias:  Ami1251
 Alias:  Amiga1251
 Alias:  Ami-1251
 (Aliases are provided for historical reasons and should not be used)
+Alias: csAmiga1251
                                                               [Malyshev]
 
 Name:  KOI7-switched
 MIBenum:  2105
 Source:  See <http://www.iana.org/assignments/charset-reg/KOI7-switched>
-Aliases:  None
+Alias:  csKOI7switched
 
 Name: BRF
 MIBenum: 2106
@@ -3037,56 +3071,57 @@ Alias: csCP51932
 Name: windows-874
 MIBenum: 2109
 Source: See <http://www.iana.org/assignments/charset-reg/windows-874>              [Steele]
-Alias: None
+Alias: cswindows874
 
 Name: windows-1250
 MIBenum: 2250
 Source: Microsoft  (http://www.iana.org/assignments/charset-reg/windows-1250) [Lazhintseva]
-Alias: None
+Alias: cswindows1250
 
 Name: windows-1251
 MIBenum: 2251
 Source: Microsoft  (http://www.iana.org/assignments/charset-reg/windows-1251) [Lazhintseva]
-Alias: None
+Alias: cswindows1251
 
 Name: windows-1252
 MIBenum: 2252
 Source: Microsoft  (http://www.iana.org/assignments/charset-reg/windows-1252)       [Wendt]
-Alias: None
+Alias: cswindows1252
 
 Name: windows-1253
 MIBenum: 2253
 Source: Microsoft  (http://www.iana.org/assignments/charset-reg/windows-1253) [Lazhintseva]
-Alias: None
+Alias: cswindows1253
 
 Name: windows-1254
 MIBenum: 2254
 Source: Microsoft  (http://www.iana.org/assignments/charset-reg/windows-1254) [Lazhintseva]
-Alias: None
+Alias: cswindows1254
 
 Name: windows-1255
 MIBenum: 2255
 Source: Microsoft  (http://www.iana.org/assignments/charset-reg/windows-1255) [Lazhintseva]
-Alias: None
+Alias: cswindows1255
 
 Name: windows-1256
 MIBenum: 2256
 Source: Microsoft  (http://www.iana.org/assignments/charset-reg/windows-1256) [Lazhintseva]
-Alias: None 
+Alias: cswindows1256
 
 Name: windows-1257
 MIBenum: 2257
 Source: Microsoft  (http://www.iana.org/assignments/charset-reg/windows-1257) [Lazhintseva]
-Alias: None
+Alias: cswindows1257
 
 Name: windows-1258
 MIBenum: 2258
 Source: Microsoft  (http://www.iana.org/assignments/charset-reg/windows-1258) [Lazhintseva]
-Alias: None
+Alias: cswindows1258
 
 Name: TIS-620
 MIBenum: 2259
 Source: Thai Industrial Standards Institute (TISI)                             [Tantsetthi]
+Alias: csTIS620
 
 Name: CP50220
 MIBenum: 2260
